@@ -45,6 +45,7 @@ from .opentherm import (
     LB,
     OPENTHERM_MESSAGES,
     OPENTHERM_MSG_TYPE,
+    R8810A_MSG_IDS,
     S8,
     U8,
     VAL,
@@ -257,7 +258,12 @@ def parser_decorator(func):
                     f"Expecting payload to match regex: '{regex}'"
                 )
         except KeyError:
-            pass
+            pass  # TODO: raise
+
+        if msg.code == "3220" and int(msg.raw_payload[4:6], 16) not in R8810A_MSG_IDS:
+            raise CorruptPayloadError(
+                f"Unsupported OpenTherm msg_id: 0x{msg.raw_payload[4:6]}"
+            )
 
     def wrapper(*args, **kwargs) -> Optional[dict]:
         """Check the length of a payload."""
@@ -1419,10 +1425,7 @@ def parser_22d0(payload, msg) -> Optional[dict]:
 
 @parser_decorator  # boiler_setpoint
 def parser_22d9(payload, msg) -> Optional[dict]:
-    assert msg.len == 3, msg.len
-    assert payload[:2] == "00", payload[:2]
-
-    return {"boiler_setpoint": _temp(payload[2:6])}
+    return {"boiler_setpoint": _temp(msg.raw_payload[2:6])}
 
 
 @parser_decorator  # switch_mode
@@ -1431,12 +1434,11 @@ def parser_22f1(payload, msg) -> Optional[dict]:
     # 11:42:49.587 071  I 052 --:------ --:------ 49:086353 22F1 003 000404
     # 11:42:49.685 072  I 052 --:------ --:------ 49:086353 22F1 003 000404
     # 11:42:49.784 072  I 052 --:------ --:------ 49:086353 22F1 003 000404
-    assert msg.len == 3, msg.len
-    assert payload[:2] == "00", payload[:2]  # has no domain
-    assert payload[4:] in ("04", "0A"), payload[4:]
+    # assert payload[:2] == "00", payload[:2]  # has no domain
+    assert int(payload[2:4], 16) <= int(payload[4:], 16), "step_idx not <= step_max"
+    # assert payload[4:] in ("04", "0A"), payload[4:]
 
     bitmap = int(payload[2:4], 16)
-    _bitmap = {"_bitmap": bitmap}
 
     if bitmap in FanSwitch.FAN_MODES:
         _action = {FanSwitch.FAN_MODE: FanSwitch.FAN_MODES[bitmap]}
@@ -1447,8 +1449,8 @@ def parser_22f1(payload, msg) -> Optional[dict]:
 
     return {
         **_action,
-        **_bitmap,
-        "unknown_0": payload[4:],
+        "step_idx": int(payload[2:4], 16),
+        "step_max": int(payload[4:6], 16),
     }
 
 
@@ -1662,7 +1664,7 @@ def parser_313f(payload, msg) -> Optional[dict]:
     return result
 
 
-@parser_decorator  # heat_demand (of device, FC domain)
+@parser_decorator  # heat_demand (of device, FC domain) - valve status (%open)
 def parser_3150(payload, msg) -> Optional[dict]:
     # event-driven, and periodically; FC domain is maximum of all zones
     # TODO: all have a valid domain will UFC/CTL respond to an RQ, for FC, for a zone?
@@ -1688,7 +1690,7 @@ def parser_3150(payload, msg) -> Optional[dict]:
     return _parser(payload)  # TODO: check UFC/FC is == CTL/FC
 
 
-@parser_decorator  # ???
+@parser_decorator  # ventilation status
 def parser_31d9(payload, msg) -> Optional[dict]:
     assert payload[:2] in ("00", "01", "21"), payload[2:4]
     assert payload[2:4] in ("00", "06", "80"), payload[2:4]
@@ -1768,7 +1770,7 @@ def parser_31da(payload, msg) -> Optional[dict]:
 
     assert payload[2:4] in ("00", "EF"), payload[2:4]
     assert payload[4:6] in ("00", "40"), payload[4:6]
-    assert payload[6:10] in ("07D0", "7FFF"), payload[6:10]
+    # assert payload[6:10] in ("07D0", "7FFF"), payload[6:10]
     assert payload[10:12] == "EF" or int(payload[10:12], 16) <= 100, payload[10:12]
     assert payload[12:14] == "EF", payload[12:14]
     assert payload[14:18] == "7FFF", payload[14:18]
@@ -1952,10 +1954,12 @@ def parser_3ef0(payload, msg) -> dict:
         if payload[2:4] != "FF":
             assert int(payload[2:4], 16) <= 100, f"byte 1: {payload[2:4]}"
         assert payload[4:6] in ("10", "11"), f"byte 2: {payload[4:6]}"
-        assert payload[8:10] in ("00", "01", "FF"), f"byte 4: {payload[8:10]}"
-        assert payload[10:12] in ("00", "FF"), f"byte 5: {payload[10:12]}"
+        assert int(payload[6:8], 16) & 0b11110000 == 0, f"byte 3: {payload[6:8]}"
+        assert payload[8:10] in ("00", "01", "0A", "FF"), f"byte 4: {payload[8:10]}"
+        assert payload[10:12] in ("00", "1C", "FF"), f"byte 5: {payload[10:12]}"
 
     if msg.len > 6:  # <= 9: # for some OTB
+        assert int(payload[12:14], 16) & 0b11111100 == 0, f"byte 6: {payload[12:14]}"
         assert payload[-2:] in ("00", "64"), f"byte x: {payload[-2:]}"
 
     result = {
@@ -1972,9 +1976,9 @@ def parser_3ef0(payload, msg) -> dict:
         result.update(
             {
                 "_unknown_3": _flag8(payload[6:8]),
-                "flame_active": bool(int(payload[6:8], 0x10) & 1 << 3),
-                "dhw_active": bool(int(payload[6:8], 0x10) & 1 << 2),
                 "ch_enabled": bool(int(payload[6:8], 0x10) & 1 << 1),
+                "dhw_active": bool(int(payload[6:8], 0x10) & 1 << 2),
+                "flame_active": bool(int(payload[6:8], 0x10) & 1 << 3),
                 "_unknown_4": payload[8:10],
                 "_unknown_5": payload[10:12],
             }
