@@ -38,16 +38,7 @@ from .const import DTM_LONG_REGEX, HGI_DEV_ADDR, __dev_mode__
 from .helpers import dt_now, dt_str
 from .packet import _PKT_LOGGER, Packet
 from .protocol import create_protocol_factory
-from .schema import (
-    ALLOW_LIST,
-    BLOCK_LIST,
-    DISABLE_SENDING,
-    ENFORCE_ALLOWLIST,
-    ENFORCE_BLOCKLIST,
-    EVOFW_FLAG,
-    SERIAL_CONFIG,
-    SERIAL_CONFIG_SCHEMA,
-)
+from .schema import ALLOW_LIST, BLOCK_LIST, SERIAL_CONFIG_SCHEMA
 from .version import __version__
 
 DEV_MODE = __dev_mode__ and False
@@ -274,14 +265,14 @@ class PacketProtocolBase(asyncio.Protocol):
         self._recv_buffer = bytes()
 
         self._include = (
-            list(gwy._include.keys()) if gwy.config[ENFORCE_ALLOWLIST] else []
+            list(gwy._include.keys()) if gwy.config.enforce_allow_list else []
         )
         self._exclude = (
-            list(gwy._exclude.keys()) if gwy.config[ENFORCE_BLOCKLIST] else []
+            list(gwy._exclude.keys()) if gwy.config.enforce_block_list else []
         )
 
         self._has_initialized = None
-        if not self._gwy.config[DISABLE_SENDING]:
+        if not self._gwy.config.disable_sending:
             self._loop.create_task(self.send_data(INIT_CMD))  # HACK: port wakeup
 
     def connection_made(self, transport: asyncio.Transport) -> None:
@@ -304,13 +295,12 @@ class PacketProtocolBase(asyncio.Protocol):
             "# ramses_rf %s", __version__, extra=self._extra(dt_str(), "")
         )
 
-        self._loop.create_task(
-            self._send_data(bytes("!V\r\n".encode("ascii")), ignore_pause=False)
-        )  # Used to see if using a evofw3 rather than a HGI80
-        self._pause_writing = False  # TODO: needs work
+        # Used to see if using a evofw3 rather than a HGI80  # TODO: needs work
+        self._loop.create_task(self._send_data("!V", ignore_pause=False))
+        self.resume_writing()
 
     @functools.lru_cache(maxsize=128)
-    def is_wanted(self, src_addr, dst_addr) -> bool:
+    def _is_wanted(self, src_addr, dst_addr) -> bool:
         """Parse the packet, return True if the packet is not to be filtered out."""
         pkt_addrs = {src_addr, dst_addr}
         if any(d.type == "18" for d in pkt_addrs):  # TODO: use GWY's full addr
@@ -369,11 +359,9 @@ class PacketProtocolBase(asyncio.Protocol):
             pkt = Packet(pkt_dtm, dtm_str, pkt_str, raw_pkt_line=pkt_raw)
         except ValueError:  # not a valid packet
             return
-        if _LOGGER.getEffectiveLevel() == logging.INFO:  # i.e. don't log for DEBUG
-            _LOGGER.info(pkt)
         self._has_initialized = True
 
-        if self._callback and self.is_wanted(pkt.src_addr, pkt.dst_addr):
+        if self._callback and self._is_wanted(pkt.src_addr, pkt.dst_addr):
             self._callback(pkt)  # only wanted PKTs up to the MSG transport's handler
 
     def data_received(self, data: ByteString) -> None:
@@ -397,17 +385,15 @@ class PacketProtocolBase(asyncio.Protocol):
                 )
                 return pkt_dtm, None, pkt_raw
 
-            if (  # "# evofw3" in pkt_str
-                "# evofw3" in pkt_str
-                and self._gwy.config.get(EVOFW_FLAG)
-                and self._gwy.config[EVOFW_FLAG] != "!V"
-            ):
-                flag = self._gwy.config[EVOFW_FLAG]
-                data = bytes(f"{flag}\r\n".encode("ascii"))
-                self._loop.create_task(self._send_data(data, ignore_pause=True))
+            if "# evofw" in pkt_str and self._gwy.config.evofw_flag not in (None, "!V"):
+                self._loop.create_task(
+                    self._send_data(self._gwy.config.evofw_flag, ignore_pause=True)
+                )
 
-            if DEV_MODE:  # TODO: deleteme
-                _LOGGER.debug("Rx: %s", pkt_raw, extra=self._extra(dtm_str, pkt_raw))
+            if DEV_MODE:  # TODO: deleteme?
+                _LOGGER.debug("RF Rx: %s", pkt_raw, extra=self._extra(dtm_str, pkt_raw))
+            elif _LOGGER.getEffectiveLevel() == logging.INFO:
+                _LOGGER.info("RF Rx: %s", pkt_raw)
 
             return pkt_dtm, dtm_str, self._normalise(pkt_str), pkt_raw
 
@@ -421,7 +407,7 @@ class PacketProtocolBase(asyncio.Protocol):
                 if pkt_str:
                     self._data_received(pkt_dtm, dtm_str, pkt_str, pkt_raw)
 
-    async def _send_data(self, data: ByteString, ignore_pause=False) -> None:
+    async def _send_data(self, data: str, ignore_pause=False) -> None:
         """Send a bytearray to the transport (serial) interface.
 
         The _pause_writing flag can be ignored, is useful for sending traceflags.
@@ -439,10 +425,15 @@ class PacketProtocolBase(asyncio.Protocol):
             )
         ):
             await asyncio.sleep(0.005)
-        if DEV_MODE:  # TODO: deleteme
-            _LOGGER.debug("Tx:     %s", data, extra=self._extra(dt_str(), data))
 
-        self._transport.write(data)
+        data = bytes(data.encode("ascii"))
+
+        if DEV_MODE:  # TODO: deleteme?
+            _LOGGER.debug("RF Tx:     %s", data, extra=self._extra(dt_str(), data))
+        elif _LOGGER.getEffectiveLevel() == logging.INFO:
+            _LOGGER.info("RF Tx:     %s", data)
+
+        self._transport.write(data + b"\r\n")
         # 0.2: can still exceed with back-to-back restarts
         # await asyncio.sleep(0.2)  # TODO: RF Duty cycle, make configurable?
 
@@ -450,7 +441,7 @@ class PacketProtocolBase(asyncio.Protocol):
         """Called when some data is to be sent (not a callback)."""
         _LOGGER.debug("PktProtocol.send_data(%s)", cmd)
 
-        if self._gwy.config[DISABLE_SENDING]:
+        if self._gwy.config.disable_sending:
             raise RuntimeError("Sending is disabled")
 
         if not cmd.is_valid:
@@ -461,13 +452,10 @@ class PacketProtocolBase(asyncio.Protocol):
 
         if cmd.from_addr.type != "18":
             _LOGGER.warning("PktProtocol.send_data(%s): IMPERSONATING!", cmd.tx_header)
-            kmd = Command._puzzle("02", cmd.tx_header)
-            await self._send_data(bytes(f"{kmd}\r\n".encode("ascii")))
+            await self._send_data(str(Command._puzzle("02", cmd.tx_header)))
 
-        # self._loop.create_task(
-        #     self._send_data(bytes(f"{cmd}\r\n".encode("ascii")))
-        # )
-        await self._send_data(bytes(f"{cmd}\r\n".encode("ascii")))
+        # self._loop.create_task(self._send_data(str(cmd)))
+        await self._send_data(str(cmd))
 
     def connection_lost(self, exc: Optional[Exception]) -> None:
         """Called when the connection is lost or closed."""
@@ -479,15 +467,11 @@ class PacketProtocolBase(asyncio.Protocol):
     def pause_writing(self) -> None:
         """Called when the transport's buffer goes over the high-water mark."""
         _LOGGER.debug("PktProtocol.pause_writing()")
-        # self._transport.get_write_buffer_size()
-
         self._pause_writing = True
 
     def resume_writing(self) -> None:
         """Called when the transport's buffer drains below the low-water mark."""
         _LOGGER.debug("PktProtocol.resume_writing()")
-        # self._transport.get_write_buffer_size()
-
         self._pause_writing = False
 
     @staticmethod
@@ -630,8 +614,6 @@ class PacketProtocolQos(PacketProtocolBase):
             pkt = Packet(pkt_dtm, dtm_str, pkt_str, raw_pkt_line=pkt_raw)
         except ValueError:  # not a valid packet
             return
-        if _LOGGER.getEffectiveLevel() == logging.INFO:  # i.e. don't log for DEBUG
-            _LOGGER.info(pkt)
         self._has_initialized = True
 
         if self._qos_cmd:
@@ -685,7 +667,7 @@ class PacketProtocolQos(PacketProtocolBase):
             # self._timeouts(dt.now())
             _logger_rcvd(_LOGGER.debug, "XXXXXXX - ")
 
-        if self._callback and self.is_wanted(pkt.src_addr, pkt.dst_addr):
+        if self._callback and self._is_wanted(pkt.src_addr, pkt.dst_addr):
             self._callback(pkt)  # only wanted PKTs up to the MSG transport's handler
 
     async def send_data(self, cmd: Command) -> None:
@@ -708,9 +690,9 @@ class PacketProtocolQos(PacketProtocolBase):
                 # see also: MsgTransport._pkt_receiver()
                 _LOGGER.error("PktProtocolQos.send_data(%s): Expired callback", hdr)
                 callback[FUNC](False, *callback.get(ARGS, tuple()))
-                callback["expired"] = not callback.get(DEAMON, False)
+                callback["expired"] = not callback.get(DEAMON, False)  # HACK:
 
-        if self._gwy.config[DISABLE_SENDING]:
+        if self._gwy.config.disable_sending:
             raise RuntimeError("Sending is disabled")
 
         if not cmd.is_valid:
@@ -735,16 +717,16 @@ class PacketProtocolQos(PacketProtocolBase):
                 "PacketProtocolQos.send_data(%s): IMPERSONATING!", cmd.tx_header
             )
             kmd = Command._puzzle("02", cmd.tx_header)
-            await self._send_data(bytes(f"{kmd}\r\n".encode("ascii")))
+            await self._send_data(str(kmd))
 
         self._timeouts(dt.now())
-        await self._send_data(bytes(f"{cmd}\r\n".encode("ascii")))
+        await self._send_data(str(cmd))
 
         while self._qos_cmd is not None:  # until sent (may need re-transmit) or expired
             await asyncio.sleep(0.005)
             if self._timeout_full > dt.now():
                 await asyncio.sleep(0.02)
-                # await self._send_data(bytes("\r\n".encode("ascii")))
+                # await self._send_data("")
 
             elif self._qos_cmd is None:  # can be set to None by data_received
                 continue
@@ -755,11 +737,11 @@ class PacketProtocolQos(PacketProtocolBase):
                 if not self._qos_cmd.qos.get("disable_backoff", False):
                     self._backoff = min(self._backoff + 1, QOS_MAX_BACKOFF)
                 self._timeouts(dt.now())
-                await self._send_data(bytes(f"{cmd}\r\n".encode("ascii")))
+                await self._send_data(str(cmd))
                 _logger_send(
-                    _LOGGER.debug,
+                    _LOGGER.warning,
                     f"RE-SENT ({self._tx_retries}/{self._tx_retry_limit})",
-                )  # TODO: should be info/debug
+                )  # TODO: should be debug
 
             else:
                 if self._qos_cmd.code != "7FFF":  # HACK: why expired when shouldn't
@@ -801,7 +783,7 @@ def create_pkt_stack(
     def _protocol_factory():
         if packet_dict or packet_log:
             return create_protocol_factory(PacketProtocolRead, gwy, msg_handler)()
-        elif gwy.config[DISABLE_SENDING]:
+        elif gwy.config.disable_sending:
             return create_protocol_factory(PacketProtocol, gwy, msg_handler)()
         else:
             return create_protocol_factory(PacketProtocolQos, gwy, msg_handler)()
@@ -818,7 +800,7 @@ def create_pkt_stack(
         return (pkt_protocol, pkt_transport)
 
     ser_config = DEFAULT_SERIAL_CONFIG
-    ser_config.update(gwy.config[SERIAL_CONFIG])
+    ser_config.update(gwy.config.serial_config)
 
     try:
         ser_instance = serial_for_url(ser_port, **ser_config)
